@@ -8,7 +8,7 @@ import re
 import torch
 import numpy as np
 import random
-
+from collections import OrderedDict
 from pathlib import Path
 import yaml
 
@@ -121,12 +121,14 @@ def generate_data_yaml(exp, labelmap, config_path):
         os.makedirs(config_path)
     data_config_path = os.path.join(config_path, "data_config.yaml")
     n_classes = len(labelmap)
+    labelmap = {int(k): v for k, v in labelmap.items()}
+    ordered_labelmap = dict(sorted(OrderedDict(labelmap).items()))
     data_config = {
         "train": os.path.join(cwd, exp.png_dir, "train"),
         "val": os.path.join(cwd, exp.png_dir, "val"),
         "test": os.path.join(cwd, exp.png_dir, "test"),
         "nc": n_classes,
-        "names": list(labelmap.values()),
+        "names": list(ordered_labelmap.values()),
     }
     with open(data_config_path, "w+") as f:
         yaml.dump(data_config, f, allow_unicode=True)
